@@ -95,6 +95,11 @@ def main(
     Create a Drupal site template with NAME.
     Where NAME is the name of your application package (e.g., axelerant/site)
     """
+    if "/" not in name:
+        util.write_error(
+            "The name argument should consist of vendor name and project name, separated by /."
+        )
+
     if not no_install:
         ensure_memory_limit()
 
@@ -210,7 +215,9 @@ def run_composer_install():
         util.write_error("Cannot find composer. Aborting...")
         sys.exit(4)
 
-    composer_run = subprocess.run("composer install -o", shell=True, check=False)
+    composer_run = subprocess.run(
+        "composer install --ignore-platform-reqs -o", shell=True, check=False
+    )
     if composer_run.returncode != 0:
         util.write_error("Error when running 'composer install'. Aborting...")
         util.write_error("Make sure you have set an adequate PHP memory limit.")
@@ -256,6 +263,12 @@ def generate_drupal_files(
     os.makedirs("config/sync", mode=0o755, exist_ok=True)
     util.write_file("config/sync/.gitkeep", "")
 
+    os.makedirs(docroot + "/modules/custom", mode=0o755, exist_ok=True)
+    util.write_file(docroot + "/modules/custom/.gitkeep", "")
+
+    os.makedirs(docroot + "/themes/custom", mode=0o755, exist_ok=True)
+    util.write_file(docroot + "/themes/custom/.gitkeep", "")
+
     util.copy_package_file("files/drupal/renovate.json", "renovate.json")
 
 
